@@ -92,31 +92,57 @@ def connect(engine_tag, *args, remove_conflicts=False, **kwds):
 
 	return Connection(engine_obj, remove_conflicts=remove_conflicts)
 
-def _tupleToSearchCondition(*args, engine):
-	"""Transform tuple (path, operator, value) to Condition object"""
+def _isNotSearchCondition(arg):
+	"""
+	Check whether supplied argument looks like search condition.
+	If it is a scalar, or a list of scalars - it is definitely not a condition.
+	"""
+	if not isinstance(arg, list):
+		return True
 
-	# do not check whether the first argument is really NOT
-	if len(args) == 3:
-		invert = False
-		shift = 0
-	elif len(args) == 4:
-		invert = True
-		shift = 1
-	elif len(args) == 0:
+	for elem in arg:
+		if isinstance(elem, list):
+			return False
+
+	return True
+
+def _listToSearchCondition(arg, engine, invert=False):
+	"""Recursively transform list to Condition object"""
+
+	if len(arg) == 0:
 		return None
-	else:
+
+	shift = 0
+	if arg[0] == op.NOT:
+		invert = not invert
+		shift = 1
+
+	# if number of arguments is even, something is wrong
+	if (len(arg) - shift) % 2 == 0:
 		raise interface.FormatError("Wrong number of elements in search condition")
 
-	operand1 = args[shift]
-	operand2 = args[2 + shift]
-	operator = args[shift + 1]
+	# condition should have one of two formats:
+	#   condition, [operator, condition, [...]]
+	#   field, comparison, value
+	if _isNotSearchCondition(arg[shift]):
+		if len(arg) - shift != 3:
+			raise interface.FormatError("Wrong number of elements in search condition")
+		return interface.SearchRequest.Condition(
+			Field(engine, arg[shift]), arg[shift + 1],
+			Field(engine, [], arg[shift + 2]), invert=invert)
+	else:
+		for i in range(shift, len(arg), 2):
+			if _isNotSearchCondition(arg[i]):
+				raise interface.FormatError("Wrong compound search condition")
 
-	operand1 = (_tupleToSearchCondition(*operand1, engine=engine)
-		if isinstance(operand1, tuple) else Field(engine, operand1))
-	operand2 = (_tupleToSearchCondition(*operand2, engine=engine)
-		if isinstance(operand2, tuple) else Field(engine, [], operand2))
-
-	return interface.SearchRequest.Condition(operand1, args[1 + shift], operand2, invert)
+		result = _listToSearchCondition(arg[shift], engine)
+		for i in range(shift + 1, len(arg), 2):
+			operator = arg[i]
+			operand2 = _listToSearchCondition(arg[i + 1], engine)
+			result = interface.SearchRequest.Condition(result, operator, operand2)
+		if invert:
+			result.invert = not result.invert
+		return result
 
 @decorator
 def _transacted(func, obj, *args, **kwds):
@@ -196,8 +222,10 @@ def _transformResults(requests, results):
 		elif isinstance(request, interface.ReadRequest):
 			res.append(_fieldsToTree(result))
 		elif isinstance(request, interface.DumpRequest):
-			for obj_id in result:
-				result[obj_id] = _fieldsToTree(result[obj_id])
+			for i, e in enumerate(result):
+				# IDs have even indexes, lists of fields have odd ones
+				if i % 2 == 1:
+					result[i] = _fieldsToTree(result[i])
 			res.append(result)
 
 	return res
@@ -434,11 +462,16 @@ class Connection:
 	def search(self, *condition):
 		"""
 		Search for object with specified fields.
-		condition - ([NOT, ]condition, operator, condition) or
-		([NOT, ]field_name, operator, value)
+		condition - [[NOT, ]condition, operator, condition] or
+		[[NOT, ]field_name, operator, value]
 		Returns list of object IDs.
 		"""
-		condition_obj = _tupleToSearchCondition(*condition, engine=self._engine)
+
+		# syntax sugar: you may not wrap plain condition in a list
+		if len(condition) != 1:
+			condition = list(condition)
+
+		condition_obj = _listToSearchCondition(condition, engine=self._engine)
 		self._requests.append(interface.SearchRequest(condition_obj))
 
 	@_transacted
@@ -471,7 +504,7 @@ class Connection:
 	def dump(self):
 		"""
 		Dump the whole database contents.
-		Returns map of object IDs to object contents.
+		Returns list [obj_id1, contents1, obj_id2, contents2, ...]
 		"""
 		self._requests.append(interface.DumpRequest())
 
@@ -479,56 +512,3 @@ class Connection:
 	def repair(self):
 		"""Rebuild caching tables in database using existing contents."""
 		self._requests.append(interface.RepairRequest())
-
-
-class FakeConnection:
-	"""
-	Class which mimics some Connection methods, implementing them using Python data structures.
-	It is used to test request results for real Connection class
-	"""
-
-	def __init__(self):
-		self._id_counter = 0
-		self._root = {}
-
-	def _getPath(self, obj, path):
-		"""Get pointer to data structure with given path"""
-		if len(path) == 1:
-			return obj[path[0]]
-		else:
-			return self._getPath(obj[path[0]], path[1:])
-
-	def _deleteAll(self, obj, path):
-		"""Delete all values from given path"""
-		if len(path) == 1:
-			del obj[path[0]]
-		else:
-			self._deleteAll(obj[path[0]], path[1:])
-
-	def create(self, data, path=None):
-		if path is None:
-			path = []
-		self._id_counter += 1
-		_saveTo(self._root, self._id_counter, path, data)
-		return self._id_counter
-
-	def modify(self, id, path, value, remove_conflicts=False):
-		_saveTo(self._root, id, path, value)
-
-	def insertMany(self, id, path, values, remove_conflicts=False):
-		target = self._getPath(self._root, [id] + path[:-1])
-		index = path[-1]
-
-		if index is None:
-			for value in values:
-				target.append(value)
-		else:
-			for value in reversed(values):
-				target.insert(index, value)
-
-	def deleteMany(self, id, paths=None):
-		for path in paths:
-			self._deleteAll(self._root, [id] + path)
-
-	def read(self, id):
-		return self._root[id]
