@@ -691,7 +691,7 @@ Get all database contents.
 
 **Arguments**: ``dump()``
 
-**Returns**: dictionary {object ID: object contents}
+**Returns**: list [object 1 ID, object 1 contents, object 2 ID, object 2 contents, ...]
 
 **Example**:
 
@@ -699,7 +699,7 @@ Get all database contents.
  >>> id1 = conn.create([1, 2, 3])
  >>> id2 = conn.create({'key': 'val'})
  >>> print(conn.dump())
- {1: [1, 2, 3], 2: {'key': 'val'}}
+ [1, [1, 2, 3], 2, {'key': 'val'}]
  >>> conn.close()
 
 .. _Connection.insert():
@@ -975,18 +975,34 @@ Search for objects in database which satisfy given conditions.
 **Arguments**: ``search(condition)``
 
 ``condition``:
-  Tuple ([``brain.op.NOT``, ] ``condition``, logical_operator, ``condition``),
-  ([``brain.op.NOT``, ] `path`_, comparison_operator, value) or (). Logical_operator and
-  comparison_operator - any `operators`_. Value should be a scalar of supported
-  type. Note that different values support different type of comparisons;
-  see `brain.op`_ reference for details.
+  One of three possibilities:
 
-  If `Connection.search()`_ is called without parameters, list of all existing object IDs is returned.
+  * List [``brain.op.NOT``, ] ``condition``, [[logical_operator, ``condition``, ] ... ]
+
+  * List [``brain.op.NOT``, ] `path`_, comparison_operator, value
+
+  * Empty list (only at root level, cannot be a part of condition)
+
+  On the root level, you may not wrap condition in a list, but rather just pass
+  it as a tuple of arguments to function.
+
+  Logical_operator and comparison_operator - any `operators`_. Value should be a
+  scalar of supported type. Note that different values support different type of
+  comparisons; see `brain.op`_ reference for details.
+
+  If ``condition`` is an empty list, it matches all existing object IDs in database.
 
   If condition uses path, not existing in some object, condition is considered
   to be false for this object if it does not contain ``brain.op.NOT`` and true
   otherwise.
 
+  Compound conditions are evaluated successively: ``[cond1, op1, cond2, op2, cond3]`` is evaluated
+  as ``[[cond1, op1, cond2], op2, cond3]``.
+
+  In compound conditions ``NOT`` applies to the result of the whole condition, not to the first
+  operand: ``[NOT, cond1, op1, cond2, op2, cond3]`` is evaluated as
+  ``[NOT, [[cond1, op1, cond2], op2, cond3]]``.
+
 **Returns**: list of object IDs, satisfying given conditions (note that order can
 depend on DB engine).
 
@@ -998,6 +1014,11 @@ depend on DB engine).
  >>> id2 = conn.create({'name': 'Bob', 'height': 180, 'age': 25})
  >>> id3 = conn.create({'name': 'Carl', 'height': 170, 'age': 26})
 
+* Empty condition
+
+ >>> print(set(conn.search()) == set([id1, id2, id3]))
+ True
+
 * Simple condition
 
  >>> print(conn.search(['name'], op.EQ, 'Alex') == [id1])
@@ -1005,14 +1026,14 @@ depend on DB engine).
 
 * Compound condition
 
- >>> print(set(conn.search((['name'], op.EQ, 'Alex'), op.OR,
- ... (['name'], op.EQ, 'Carl'))) == set([id1, id3]))
+ >>> print(set(conn.search([['name'], op.EQ, 'Alex'], op.OR,
+ ... [['name'], op.EQ, 'Carl'])) == set([id1, id3]))
  True
 
 * Compound condition with negative
 
- >>> print(set(conn.search((['name'], op.EQ, 'Alex'), op.OR,
- ... (op.NOT, ['name'], op.EQ, 'Carl'))) == set([id1, id2]))
+ >>> print(set(conn.search([['name'], op.EQ, 'Alex'], op.OR,
+ ... [op.NOT, ['name'], op.EQ, 'Carl'])) == set([id1, id2]))
  True
 
 * Condition with non-equality
@@ -1022,14 +1043,21 @@ depend on DB engine).
 
 * Condition with non-existent field
 
- >>> print(conn.search((['name'], op.EQ, 'Alex'), op.AND,
- ... (['weight'], op.GT, 0)) == [])
+ >>> print(conn.search([['name'], op.EQ, 'Alex'], op.AND,
+ ... [['height'], op.EQ, 180]) == [])
  True
 
 * Condition with non-existent field and negative
 
- >>> print(conn.search((['name'], op.EQ, 'Alex'), op.AND,
- ... (op.NOT, ['weight'], op.GT, 0)) == [id1])
+ >>> print(conn.search([['name'], op.EQ, 'Alex'], op.AND,
+ ... [op.NOT, ['height'], op.EQ, 180]) == [id1])
+ True
+
+* Long compound condition
+
+ >>> print(conn.search([['name'], op.EQ, 'Alex'], op.OR,
+ ... [['age'], op.EQ, 25], op.AND,
+ ... [['height'], op.GT, 175]) == [id2])
  True
  >>> conn.close()
 
@@ -1039,14 +1067,7 @@ Client
 XML RPC client for brain DB. Based on Python's built-in ``xmlrpc.client.ServerProxy`` and has the
 following extensions:
 
-* Supports tuples (marshaling only): marshaled in XML same as arrays, but tag is
-  ``<tuple>`` instead of ``<array>``
-
-* Supports non-string dictionary keys (unmarshaling only)
-
-* Supports keyword arguments (marshaling only)
-
-* Transforms ``bytes()`` to ``Binary`` implicitly during marshaling
+* Supports keyword arguments to calls (adds dictionary with keyword argument to each method call)
 
 * Unmarshalls known `exceptions`_ from ``Faults`` returned by server
 
@@ -1078,15 +1099,9 @@ Server
 ~~~~~~
 
 XML RPC server for database. Based on Python's built-in ``xmlrpc.server.DocXMLRPCServer``
-and has the following extensions:
-
-* Supports tuples (unmarshaling only): marshaled in XML same as arrays, but tag is
-  ``<tuple>`` instead of ``<array>``
-
-* Supports non-string dictionary keys (marhsalling only)
-
-* Supports keyword arguments (unmarshaling only). They are passed as the dictionary in additional
-  argument to each function. If function does not have any keyword arguments, empty dictionary is passed.
+and extends standard XML RPC slightly: it supports keyword arguments to calls.
+They are passed as the dictionary in additional argument to each function.
+If function does not have any keyword arguments, empty dictionary is passed.
 
 **Arguments**: ``Server(port=8000, name=None, db_path=None)``
 
